@@ -63,6 +63,7 @@ async def single(data: Single):
         patient = data['patient']
         job_id = cfg.short_queue.enqueue(vcfanalysis.single,
                                          args=[patient, panel])
+        job_id = job_id.id
         return JSONResponse(status_code=status.HTTP_202_ACCEPTED,
                             content=f"Job Queued. Job id is {job_id}")
     except Exception as err:
@@ -75,9 +76,9 @@ async def single(data: Single):
 async def duos(data: Duos):
     data = data.dict()
     try:
-        patient1 = data['Patient1']
-        patient2 = data['Patient2']
-        VennPlace = data['vennplace']
+        patient1 = data['patient1']
+        patient2 = data['patient2']
+        VennPlace = data['vennPlace']
         Panel = data['panel']
         Filter = data['filter']
         job_id = cfg.short_queue.enqueue(vcfanalysis.duos,
@@ -87,6 +88,7 @@ async def duos(data: Duos):
                                              "Panel": Panel,
                                              "Filter": Filter
                                          })
+        job_id = job_id.id
         return JSONResponse(status_code=status.HTTP_202_ACCEPTED,
                             content=f"Job Queued. Job id is {job_id}")
     except Exception as err:
@@ -97,11 +99,12 @@ async def duos(data: Duos):
 
 @app.post("/modaapi/trios")
 async def trios(data: Trios):
+    data = data.dict()
     try:
-        patient1 = data['Patient3']
-        patient2 = data['Patient3']
-        patient3 = data['Patient3']
-        VennPlace = data['vennplace']
+        patient1 = data['patient1']
+        patient2 = data['patient2']
+        patient3 = data['patient3']
+        VennPlace = data['vennPlace']
         Panel = data['panel']
         Filter = data['filter']
         # Checks file existence and type for patients
@@ -112,7 +115,7 @@ async def trios(data: Trios):
                                              "Panel": Panel,
                                              "Filter": Filter
                                          })
-        job_id = job_id.job_id
+        job_id = job_id.id
         return JSONResponse(status_code=status.HTTP_202_ACCEPTED,
                             content=f"Job Queued. Job id is {job_id}")
     except Exception as err:
@@ -124,6 +127,7 @@ async def trios(data: Trios):
 @app.post("/modaapi/pipeline")
 async def run_pipeline(data: Pipeline):
     try:
+        data = data.dict()
         pipe = data['Pipeline']
 
         checkFile(pipe, data['Pipeline'].split(".")[-1])
@@ -145,7 +149,7 @@ async def run_pipeline(data: Pipeline):
                     "endStep": data['endStep'],
                 },
             )
-            job_id = job_id.job_id
+            job_id = job_id.id
             return JSONResponse(status_code=status.HTTP_202_ACCEPTED,
                                 content=f"Job Queued. Job id is {job_id}")
         else:
@@ -159,7 +163,7 @@ async def run_pipeline(data: Pipeline):
                     "endStep": data['endStep'],
                 },
             )
-            job_id = job_id.job_id
+            job_id = job_id.id
             return JSONResponse(status_code=status.HTTP_202_ACCEPTED,
                                 content=f"Job Queued. Job id is {job_id}")
     except Exception as err:
